<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * List products. One widget to rule them all.
 *
 * @author   WooThemes
 * @category Widgets
 * @package  WooCommerce/Widgets
 * @version  2.3.0
 * @extends  WC_Widget
 */
class YOURSTORE_WC_Widget_Products extends WC_Widget {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->widget_cssclass    = 'woocommerce widget_products';
		$this->widget_description = esc_html__( 'Display a list of your products on your site.', 'yourstore' );
		$this->widget_id          = 'woocommerce_products';
		$this->widget_name        = esc_html__( 'Yourstore Products', 'yourstore' );
		$this->settings           = array(
			'title'  => array(
				'type'  => 'text',
				'std'   => esc_html__( 'Products', 'yourstore' ),
				'label' => esc_html__( 'Title', 'yourstore' )
			),
			'subtitle'  => array(
				'type'  => 'text',
				'std'   => '',
				'label' => esc_html__( 'Sub-Title', 'yourstore' )
			),
			'number' => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => '',
				'std'   => 5,
				'label' => esc_html__( 'Number of products to show', 'yourstore' )
			),
			'show' => array(
				'type'  => 'select',
				'std'   => '',
				'label' => esc_html__( 'Show', 'yourstore' ),
				'options' => array(
					''         => esc_html__( 'All Products', 'yourstore' ),
					'featured' => esc_html__( 'Featured Products', 'yourstore' ),
					'onsale'   => esc_html__( 'On-sale Products', 'yourstore' ),
				)
			),
			'orderby' => array(
				'type'  => 'select',
				'std'   => 'date',
				'label' => esc_html__( 'Order by', 'yourstore' ),
				'options' => array(
					'date'   => esc_html__( 'Date', 'yourstore' ),
					'price'  => esc_html__( 'Price', 'yourstore' ),
					'rand'   => esc_html__( 'Random', 'yourstore' ),
					'sales'  => esc_html__( 'Sales', 'yourstore' ),
				)
			),
			'order' => array(
				'type'  => 'select',
				'std'   => 'desc',
				'label' => _x( 'Order', 'Sorting order', 'yourstore' ),
				'options' => array(
					'asc'  => esc_html__( 'ASC', 'yourstore' ),
					'desc' => esc_html__( 'DESC', 'yourstore' ),
				)
			),
			'hide_free' => array(
				'type'  => 'checkbox',
				'std'   => 0,
				'label' => esc_html__( 'Hide free products', 'yourstore' )
			),
			'show_hidden' => array(
				'type'  => 'checkbox',
				'std'   => 0,
				'label' => esc_html__( 'Show hidden products', 'yourstore' )
			),
			'is_slider' => array(
				'type'  => 'checkbox',
				'std'   => 0,
				'label' => esc_html__( 'Slider ?', 'yourstore' )
			)
		);

		parent::__construct();
	}

	/**
	 * Query the products and return them.
	 * @param  array $args
	 * @param  array $instance
	 * @return WP_Query
	 */
	public function get_products( $args, $instance ) {
		$number  = ! empty( $instance['number'] ) ? absint( $instance['number'] ) : $this->settings['number']['std'];
		$show    = ! empty( $instance['show'] ) ? sanitize_title( $instance['show'] ) : $this->settings['show']['std'];
		$orderby = ! empty( $instance['orderby'] ) ? sanitize_title( $instance['orderby'] ) : $this->settings['orderby']['std'];
		$order   = ! empty( $instance['order'] ) ? sanitize_title( $instance['order'] ) : $this->settings['order']['std'];

		$query_args = array(
			'posts_per_page' => $number,
			'post_status'    => 'publish',
			'post_type'      => 'product',
			'no_found_rows'  => 1,
			'order'          => $order,
			'meta_query'     => array()
		);

		if ( empty( $instance['show_hidden'] ) ) {
			$query_args['meta_query'][] = WC()->query->visibility_meta_query();
			$query_args['post_parent']  = 0;
		}

		if ( ! empty( $instance['hide_free'] ) ) {
			$query_args['meta_query'][] = array(
				'key'     => '_price',
				'value'   => 0,
				'compare' => '>',
				'type'    => 'DECIMAL',
			);
		}

		$query_args['meta_query'][] = WC()->query->stock_status_meta_query();
		$query_args['meta_query']   = array_filter( $query_args['meta_query'] );

		switch ( $show ) {
			case 'featured' :
				$tax_query   = WC()->query->get_tax_query();
				$tax_query[] = array(
					'taxonomy' => 'product_visibility',
					'field'    => 'name',
					'terms'    => 'featured',
					'operator' => 'IN',
				);
				$query_args['tax_query']   = $tax_query;
				break;
			case 'onsale' :
				$product_ids_on_sale    = wc_get_product_ids_on_sale();
				$product_ids_on_sale[]  = 0;
				$query_args['post__in'] = $product_ids_on_sale;
				 $query_args['meta_query']     = WC()->query->get_meta_query();
             $query_args['tax_query']      = WC()->query->get_tax_query();
            
				break;
		}





		switch ( $orderby ) {
			case 'price' :
				$query_args['meta_key'] = '_price';
				$query_args['orderby']  = 'meta_value_num';
				break;
			case 'rand' :
				$query_args['orderby']  = 'rand';
				break;
			case 'sales' :
				$query_args['meta_key'] = 'total_sales';
				$query_args['orderby']  = 'meta_value_num';
				break;
			default :
				$query_args['orderby']  = 'date';
		}

		return new WP_Query( apply_filters( 'woocommerce_products_widget_query_args', $query_args ) );
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		if ( $this->get_cached_widget( $args ) ) {
			return;
		}

		ob_start();

		if ( ( $products = $this->get_products( $args, $instance ) ) && $products->have_posts() ) {
			$this->widget_start( $args, $instance );
            
            if(isset($instance['subtitle']) && $instance['subtitle']){
                echo '<p>'.wp_kses_post($instance['subtitle']).'</p>';
            }
            $randid = 'vertical-carousel-'.rand(00000,99999);
            
            $offset_top = 10;
            
            $with_slider_class = '';
            
            if(isset($instance['is_slider']) && $instance['is_slider'] == 1){
                $offset_top += 30;
                $with_slider_class .= ' has-slider';
            }
            
			echo apply_filters( 'woocommerce_before_widget_product_list', '<div id="'.esc_attr($randid).'" class="product_list_widget vertical-carousel vertical-carousel-2 offset-top-'.esc_attr($offset_top.$with_slider_class).'">' );

			while ( $products->have_posts() ) {
				$products->the_post();
				wc_get_template( 'content-widget-product.php', array( 'show_rating' => true ) );
			}

			echo apply_filters( 'woocommerce_after_widget_product_list', '</div>' );

			$this->widget_end( $args );
		}

		wp_reset_postdata();
        
		print $this->cache_widget( $args, ob_get_clean() );
	}
}
