<?php

class YourstoreMainMenuWalker extends Walker_Nav_Menu
{
    private $mega_menu = false;
    private $is_mega_menu = false;
    private $mega_menu_parent = false;
    private $current_item_parent_obj = false;
    /**
	 * Starts the list before the elements are added.
	 *
	 * @see Walker::start_lvl()
	 *
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args   An array of arguments. @see wp_nav_menu()
	 */
	public function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat("\t", $depth);
        $menu_class = '';
        if($depth == 0 && $this->mega_menu){
            $menu_class .= " {$this->mega_menu}";
            $this->mega_menu = false;
        }else{
            $menu_class .= 'megamenu__submenu';
        }
		$output .= "\n{$indent}<ul class=\"".esc_attr($menu_class)."\">\n";
	}

	/**
	 * Ends the list of after the elements are added.
	 *
	 * @see Walker::end_lvl()
	 *
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args   An array of arguments. @see wp_nav_menu()
	 */
	public function end_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat("\t", $depth);
        if($depth == 0 
            && $this->is_mega_menu 
            && isset($this->current_item_parent_obj->post_content) 
            && !empty($this->current_item_parent_obj->post_content)){
            $output .= '<li class="menu-col-fullwidth">'. sprintf(__('%s','yourstore'),do_shortcode( $this->current_item_parent_obj->post_content )) 
           .'</li>';
        }
		$output .= "$indent</ul>\n";
	}
    
    public function start_el(&$output, $item, $depth = 0, $args = array(), $current_object_id = 0)
    {

        if (!isset($item->object_id)) {

            if (!is_object($args))
                $args = (object) $args;

            if (empty($item->url))
                $item->url = get_permalink($item->ID);

            if (empty($item->title))
                $item->title = $item->post_title;
        }
        if($depth == 0){
            $this->current_item_parent_obj = $item;
            $item->title = "<span class=\"act-underline\">{$item->title}";
            if(!empty($item->yourstore_label)){
                $label_css = !empty($item->label_color) ? array('background-color' => $item->label_color ) : array();
                $label_css['color'] = "#ffffff";
                $label_extra_class = '';
                if(preg_match('/^yourstore\-sidebar\-menu\-\d+$/', $args->container_id)){
                    $label_extra_class .= ' pull-right';
                }
                $random = rand(00000,99999);
                $label_element_id = 'badge-'.$item->ID.$random;
                $item->title .= '<span data-primary-menu-label=\''.json_encode($label_css).'\' id="'.esc_attr($label_element_id).'" class="badge badge--menu'.esc_attr($label_extra_class).'">' . esc_html($item->yourstore_label) . '</span>';
            }else{
                $args->link_after = '';
            }
            $item->title .= '</span>';
        }
        
        if ($depth == 0 
            && isset($item->yourstore_mega_menu) 
            && $item->yourstore_mega_menu == 'true') {
            $megamenuwidth = 'four';
            if($item->yourstore_menu_width){
                $megamenuwidth = $item->yourstore_menu_width;
            }
            $this->is_mega_menu = true;
            $item->classes[] = "dropdown dropdown-mega-menu";
            $this->mega_menu = "dropdown-menu"; // set custom menu width
            if(isset($item->yourstore_big_mega_menu) && $item->yourstore_big_mega_menu == 'true'){
                $this->mega_menu .= ' megamenu';
            }else{
                $item->classes[] = " dropdown-two-col";
                $this->mega_menu .= " multicolumn {$megamenuwidth}-col dl-submenu";
            }
            if(in_array('current-menu-item', $item->classes)){
                $item->classes[] = 'selected';
            }
        }elseif($depth == 1) {
            $itemtitle = $item->title;
            if($this->is_mega_menu){
                if(isset($this->current_item_parent_obj->yourstore_big_mega_menu) 
                    && $this->current_item_parent_obj->yourstore_big_mega_menu == 'true'){
                        $item->classes = $this->addColumnClass($item->classes);
                }
                if(isset($item->yourstore_grid_type_depth_one)){
                    switch ($item->yourstore_grid_type_depth_one){
                        case '2':
                            $item->classes[] = 'image-link';
                            $titlebeforehtml = '<span class="figure"><img class="img-responsive" src="'.esc_url($item->description).'" alt="'.esc_attr($itemtitle).'"></span>';
                            $item->title = $titlebeforehtml.'<span class="figcaption text-uppercase">'.wp_kses_post($itemtitle).'</span>';
                            break;
                        case '1':
                            if(in_array('menu-item-has-children', $item->classes)){
                                $item->classes[] = 'megamenu__subtitle';
                                $item->title = '<span>'.wp_kses_post($itemtitle).'</span>';
                            }
                            break;
                        case '3':
                            $item->classes[] = 'menu-item-html';
                        default:
                            $item->classes[] = 'megamenu__subtitle';
                            $item->title = '<span>'.wp_kses_post($itemtitle).'</span>';
                            break;
                    }
                }
                if(!in_array('menu-item-has-children', $item->classes)){
                    $item->classes[] = 'menu-item-has-no-children';
                }
                if($item->object == 'product_cat' 
                    && isset($item->yourstore_display_cat_img) 
                    && $item->yourstore_display_cat_img == 'true' 
                    && function_exists('get_term_meta')){
                    $thumbnail_id = get_term_meta((int)$item->object_id, 'thumbnail_id', true);
                    if (!empty($thumbnail_id)) {
                        $catimage = wp_get_attachment_url($thumbnail_id);
                        $item->title .= '<span class="megamenu__category-image hidden-xs"><img class="img-responsive" src="'.esc_url($catimage).'" alt="'.esc_attr($itemtitle).'"></span>';
                    }
                }
            }
        }

        if($depth > 0){
            if(!empty($item->yourstore_label)){
                $label_css = !empty($item->label_color) ? array('background-color' => $item->label_color ) : array();
                $label_css['color'] = "#ffffff";
                $label_element_id = 'badge-'.$item->ID;
                $args->link_after = '<span data-primary-menu-label=\''.json_encode($label_css).'\' id="'.esc_attr($label_element_id).'" class="badge badge--menu pull-right">' . esc_html($item->yourstore_label) . '</span>';
            }else{
                $args->link_after = '';
            }
        }

        if (!empty($item->link_bg_color)) {
            $item->classes[] = 'yourstore_highlighted';
        }
        
        parent::start_el($output, $item, $depth, $args);
    }
    private function addColumnClass($classes = array()){
        switch($this->current_item_parent_obj->yourstore_menu_width){
            case 'three':
                $classes[] = 'col-sm-4';
                break;
            case 'four':
                $classes[] = 'col-sm-3';
                break;
            case 'five':
                $classes[] = 'col-one-fifth';
                break;
            case 'six':
                $classes[] = 'col-sm-2';
                break;
            default:
                $classes[] = 'col-sm-6';
                break;
        }
        return $classes;
    }
    protected function getChildCategoryMarkup($parent)
    {
        ob_start();
        if ($parent->type == 'taxonomy' && isset($parent->yourstore_order_by)) {
            $terms = get_terms(
                $parent->object,
                array(
                    'parent' => (int) $parent->object_id,
                    'number' => (int) $parent->yourstore_display_cats_num,
                    'orderby' => $parent->yourstore_order_by,
                    'order' => $parent->yourstore_order_way,
                    'hide_empty' => false
                    ));
            if(!empty($terms) && !is_wp_error($terms)){
            ?>
            <ul class="megamenu__submenu">
                <?php foreach($terms as $term){?>
                <li class="level2"><a href="<?php echo esc_url(get_term_link($term->term_id, $term->taxonomy))?>"><?php echo esc_html($term->name)?></a></li>
                <?php }?>
            </ul>
            <?php
            }
        }
        return ob_get_clean();
    }

    public function end_el(&$output, $item, $depth = 0, $args = array())
    {

        if (isset($item->object_id)) {

              if(isset($item->yourstore_grid_type_depth_one)){
                  switch($item->yourstore_grid_type_depth_one){
                      case '4':
                          $output .= $this->getChildCategoryMarkup($item);
                          break;
                      case '3':
                          $output .= '<div class="col-sm-12">'.sprintf(__('%s','yourstore'),do_shortcode($item->post_content)).'</div>';
                          break;
                  }
                  
              }

        } else {

            if (!is_object($args))
                $args = (object) $args;

            if (empty($item->url))
                $item->url = get_permalink($item->ID);

            if (empty($item->title))
                $item->title = $item->post_title;
        }
        if($depth == 0){
            $this->is_mega_menu = false;
            $this->current_item_parent_obj = false;
        }
        parent::end_el($output, $item, $depth, $args);
    }

}

function yourstore_highlight_css($atts, $item, $args, $depth)
{

    if (!$depth && !empty($item->link_bg_color)) {
        $atts['style'] = '';
        $atts['style'] .= (!empty($item->link_bg_color)) ? 'background-color:' . $item->link_bg_color . ';' : '';
        $atts['style'] .= (!empty($item->link_color)) ? 'color:' . $item->link_color . ';' : '';
    }

    return $atts;
}
add_filter('nav_menu_link_attributes', 'yourstore_highlight_css', 10, 4);