<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product,$woocommerce_loop;

// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}
if(!isset($multiple_images)){
    $multiple_images = true;
}


$product_terms = get_the_terms(get_the_ID(), 'product_cat');
$pt_class = '';
$zoom_effect = '';

if (is_shop() || is_product_category() || (isset($is_zoom_effect) && $is_zoom_effect)) {
    $zoom_effect = 'product--zoom';
}
if(!empty($product_terms) && !is_wp_error($product_terms)){
    foreach ($product_terms as $product_term) {
        $pt_class .= esc_attr($product_term->slug) . ' ';
    }
}

$colclass = '';
$columns = $woocommerce_loop['columns'];
if (is_shop() || is_product_category() || is_product_tag()) {
    if (isset($_GET['layout'])) {
        $size = (int) $_GET['layout'];
        switch ($size) {
            case 2:
                $columns = 6;
                break;
            case 4:
                $columns = 2;
                break;
        }
    }
}
if (isset($woocommerce_loop['name']) && !empty($woocommerce_loop['name'])) {
    switch ($columns) {
        case 2:
            $colclass = ' col-xs-12 col-sm-6 col-md-6 col-lg-6 col-xl-3 ';
            break;
        case 4:
            $colclass = ' col-xs-12 col-sm-4 col-md-4 col-lg-3 col-xl-3 ';
            break;
        case 9:
            $colclass = ' col-xs-12 col-sm-4 col-md-3 col-lg-2 col-xl-one-nine ';
            break;
        case 6:
            $colclass = ' col-xs-12 col-sm-4 col-md-3 col-lg-3 col-xl-2 ';
            break;
        default:
            $colclass = ' col-xs-12 col-sm-4 col-md-6 col-lg-4 col-xl-one-fifth ';
            break;
    }
} else {
    switch ($columns) {
        case 2:
            $colclass = ' col-xs-12 col-sm-6 col-md-6 col-lg-6 col-xl-3 ';
            break;
        case 4:
            $colclass = ' col-xs-12 col-sm-4 col-md-4 col-lg-3 col-xl-3 ';
            break;
        case 9:
            $colclass = ' col-xs-12 col-sm-4 col-md-3 col-lg-2 col-xl-one-nine ';
            break;
        case 6:
            $colclass = ' col-xs-12 col-sm-12 col-md-12 col-lg-3 col-xl-12 ';
            break;
        default:
            $colclass = ' col-xs-12 col-sm-6 col-md-6 col-lg-4 col-xl-one-fifth ';
            break;
    }
}

$classes =' ys-product';
$classes = $classes.$colclass. $pt_class;
?>
<li <?php wc_product_class( $classes , '' ); ?>>
    <div class="product <?php echo esc_attr($zoom_effect); ?>">
        <div class="product__inside woocommerce">
            <?php
            /**
             * woocommerce_before_shop_loop_item hook.
             *
             * @hooked woocommerce_template_loop_product_link_open - 10
             */
            do_action('woocommerce_before_shop_loop_item');

            /*
             * woocommerce_before_shop_loop_item_title hook.
             *
             * @hooked woocommerce_show_product_loop_sale_flash - 10
             * @hooked woocommerce_template_loop_product_thumbnail - 10
            */
            do_action('woocommerce_before_shop_loop_item_title', $multiple_images);

            ?>
            <div class="product__inside__name">
                <?php
                /**
                 * woocommerce_shop_loop_item_title hook.
                 *
                 * @hooked woocommerce_template_loop_product_title - 10
                 */
                do_action('woocommerce_shop_loop_item_title');

                ?>
            </div>
            <!-- visible only in row-view mode -->
            <div class="product__inside__description row-mode-visible"><?php the_excerpt(); ?></div>
            <div>
            <?php
            /**
             * woocommerce_after_shop_loop_item_title hook.
             *
             * @hooked woocommerce_template_loop_rating - 5
             * @hooked woocommerce_template_loop_price - 10
             */
			 
            do_action('woocommerce_after_shop_loop_item_title');
			?>
            </div>
            <?php

            /**
             * woocommerce_after_shop_loop_item hook.
             *
             * @hooked woocommerce_template_loop_product_link_close - 5
             * @hooked woocommerce_template_loop_add_to_cart - 10
             */
            do_action('woocommerce_after_shop_loop_item');

            ?>
        </div>
    </div>
</li>